@@ -1,5 +1,6 @@
-__version__ = "0.1.5"
+__version__ = "0.1.7"
 
+import logging
 import os
 from typing import Any
 
@@ -7,16 +8,21 @@ from optuna import load_study, Study, Trial
 
 from pytorch_tao.args import _ArgSet, arg, arguments
 
-from pytorch_tao.core import ConfigMissingError, ensure_config, load_cfg
+from pytorch_tao.core import ConfigMissingError, ensure_arg, ensure_config, load_cfg, on
 from pytorch_tao.repo import DirtyRepoError, Repo
+from pytorch_tao.trackers import set_tracker, Tracker
+from pytorch_tao.trainer import Trainer
 from pytorch_tao.tune import tell
 
+logging.captureWarnings(True)
+
 
 args: _ArgSet = None
 study: Study = None
 trial: Trial = None
 cfg: Any = None
 repo: Repo = None
+tracker = Tracker()
 
 if os.getenv("TAO_REPO"):
     repo = Repo(os.getenv("TAO_REPO"))
@@ -31,6 +37,7 @@ __all__ = [
     "load_cfg",
     "cfg",
     "ensure_config",
+    "ensure_arg",
     "ConfigMissingError",
     "args",
     "study",
@@ -39,4 +46,7 @@ __all__ = [
     "arguments",
     "arg",
     "tell",
+    "on",
+    "Trainer",
+    "set_tracker",
 ]
